@@ -816,9 +816,10 @@ class NL80211(generic.GenericNetlinkSocket):
 		NL80211_WOWLAN_TRIG_NET_DETECT_RESULTS: attributes.array(attributes.nested(ATTRIBUTES))
 	}
 	
-	ATTRIBUTES_WOWLAN_TRIG_SUPPORTED = ATTRIBUTES_WOWLAN_TRIG | {
+	ATTRIBUTES_WOWLAN_TRIG_SUPPORTED = ATTRIBUTES_WOWLAN_TRIG.copy()
+	ATTRIBUTES_WOWLAN_TRIG_SUPPORTED.update({
 		NL80211_WOWLAN_TRIG_NET_DETECT: attributes.u32()
-	}
+	})
 	
 	ATTRIBUTES_IFACE_LIMIT = {
 		NL80211_IFACE_LIMIT_MAX: attributes.u32(),
